@@ -78,7 +78,12 @@ class Selector():
         retval = None
         if key is not None:
             # How many entries are there in this category?
-            sellen = len(self._data[key])
+            try:
+                sellen = len(self._data[key])
+            except KeyError:
+                print("KeyError in Selector for key: {0}".format(key))
+                print(jStr(self._data))
+                raise KeyError
             # Let's not try selecting on an empty set
             if sellen > 0:
                 # If I can't select after that number of tries, there's a probably an issue
@@ -103,49 +108,6 @@ class Selector():
         # Here's a result.
         return retval
 
-    def old_search(self, spath=None):
-        """Walk a directory tree to add to the Selector configuration.
-
-        This method walks the specified directory tree and adds any discovered WAV files to its inventory.
-        This method is uniquely additive in that it can be run repeatedly across the different or the same trees.
-        Uniqueness is enforced during this process, so any repeats are silently overwritten.
-        Any files encountered that do not match the criteria for a WAV file are ignored.
-
-        Args:
-            spath (str) : path to the root of the searchble directory tree.
-
-        .. code-block:: python
-           :caption: Example usage
-       
-           from GenerIter.selector import Selector
-           # Empty Selector
-           selector = Selector()
-           # Search a directory tree
-           selector.search(spath=pathstring)
-
-
-        """
-        if spath is not None:
-            #debug(spath)
-            for subdir, dirs, fyles in os.walk(spath):
-                #debug((subdir, dirs, fyles))
-                for fyle in fyles:
-                    #debug(fyle)
-                    filepath = "{0}{1}{2}".format(subdir,
-                                                  os.sep,
-                                                  fyle)
-                    #debug(filepath)
-                    # Attempt to add this item into the current configuration
-                    try:
-                        # Is it a valid WavSource?
-                        src = WavSource(dpath=filepath, dexist=True)
-                    except Exception as inst:
-                        debug(filepath)
-                        #debug_except(inst)
-                        debug("skipping ...")
-                        src = None # The insert will skip this
-                    self.insert(source=src, include=True)
-
     def search(self, spath=None):
         """Walk a directory tree to add to the Selector configuration.
 
@@ -166,14 +128,14 @@ class Selector():
            # Search a directory tree
            selector.search(spath=pathstring)
 
-
         """
         if spath is not None:
-            #debug(spath)
+            # Let's use the object-oriented filesystem abstraction
             sdir = Path(spath)
+            # Recursively walk the directory and subdirectories
             fyles = list(sdir.rglob('*.*'))
             for fyle in fyles:
-                #debug(fyle)
+                # Ensure the filepath is absolute
                 filepath = str(fyle.resolve())
                 #debug(filepath)
                 # Attempt to add this item into the current configuration
